summaryrefslogtreecommitdiffstats
path: root/kbfxlib/data/kbfxdatagroup.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-05 22:07:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-05 22:07:15 +0000
commit421b60af92c83b889f8903c2898f2bd07186fcd8 (patch)
treead873a24c9438baed4942fda795430a4c3dc9a9a /kbfxlib/data/kbfxdatagroup.h
parent39e896bddf25bf34cbf8be814d959181e2c1d1dd (diff)
downloadkbfx-421b60af92c83b889f8903c2898f2bd07186fcd8.tar.gz
kbfx-421b60af92c83b889f8903c2898f2bd07186fcd8.zip
TQt4 port kbfx
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kbfx@1230544 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbfxlib/data/kbfxdatagroup.h')
-rw-r--r--kbfxlib/data/kbfxdatagroup.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kbfxlib/data/kbfxdatagroup.h b/kbfxlib/data/kbfxdatagroup.h
index 7587502..1e3eeef 100644
--- a/kbfxlib/data/kbfxdatagroup.h
+++ b/kbfxlib/data/kbfxdatagroup.h
@@ -22,16 +22,16 @@
#ifndef KBFX_DATA_GROUP_H
#define KBFX_DATA_GROUP_H
-#include <qmap.h>
-#include <qstringlist.h>
+#include <tqmap.h>
+#include <tqstringlist.h>
#include "kbfxdatasource.h"
class KbfxDataGroup
{
public:
- typedef QMap<QString,KbfxDataSource*> Data;
- typedef QMap<int,KbfxDataSource*> Index;
+ typedef TQMap<TQString,KbfxDataSource*> Data;
+ typedef TQMap<int,KbfxDataSource*> Index;
/**
* Construts a new data group and initialzes the group
@@ -55,16 +55,16 @@ class KbfxDataGroup
* "Unknown Group" . it is recomended that a name is always set
* @param name The name that should be give to the group
*/
- void setName ( QString name ) {m_name = name;}
+ void setName ( TQString name ) {m_name = name;}
/**
* To access a datasource give the name of the datasource
* @param The name othe datasource
* @return pointer to a valid datasource
*/
- KbfxDataSource * getItem ( QString );
+ KbfxDataSource * getItem ( TQString );
/**
* use this to get all the items inside the datagroup
* @return a copy of the data Map (QMap<QString,KbfxDataSource*>)
*/
Data getData();
/**
@@ -72,12 +72,12 @@ class KbfxDataGroup
* @param keyword to search for
* @return list of matching datasources
*/
- KbfxDataSource::DataSourceList lookup ( QString );
+ KbfxDataSource::DataSourceList lookup ( TQString );
/**
* The name of the group
* @return Name of the group
*/
- QString name() {return m_name;}
+ TQString name() {return m_name;}
/**
* The number of datasources inside the datagroup
* @return number of datasources
@@ -92,7 +92,7 @@ class KbfxDataGroup
private:
Data m_data;
- QString m_name;
+ TQString m_name;
int m_count;
Index m_index;
};
@@ -55,16 +55,16 @@ class KbfxDataGroup
/**
* use this to get all the items inside the datagroup
- * @return a copy of the data Map (QMap<QString,KbfxDataSource*>)
+ * @return a copy of the data Map (TQMap<TQString,KbfxDataSource*>)
*/
Data getData();